==> ukui-panel_4.10.3.1.orig.tar.gz: ukui-panel-4.10.3.1/widgets/ukui-menu-starter/i18n/org.ukui.menu.starter_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>StartMenuButton</name>
    <message>
        <source>Switch user</source>
        <translation>Kullanıcı değiştirme</translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation>Log Out</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>DerinUyku</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya Al</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden Başlat</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>Bilgisayarı Kapat</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Start Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>File Manager</source>
        <translation>Dosya Yöneticisi</translation>
    </message>
    <message>
        <source>Terminal</source>
        <translation>Uçbirim</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Monitor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-panel_5.0.1.0.orig.tar.gz: ukui-panel-5.0.1.0/widgets/ukui-menu-starter/i18n/org.ukui.menu.starter_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>StartMenuButton</name>
    <message>
        <source>Log Out</source>
        <translation>Log Out</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>DerinUyku</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya Al</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden Başlat</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>Bilgisayarı Kapat</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>File Manager</source>
        <translation>Dosya Yöneticisi</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About This Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User or Log Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
